@@ -2,8 +2,6 @@ package Lire::Config::Build;
 
 use strict;
 
-require Exporter;
-
 use vars qw( $VERSION %ac @ISA @EXPORT_OK );
 
 sub coalesce {
@@ -13,7 +11,7 @@ sub coalesce {
 }
 
 BEGIN {
-    ($VERSION)  = '$Revision: 1.9 $' =~ m!Revision: ([.\d]+)!;
+    ($VERSION)  = '$Revision: 1.8 $' =~ m!Revision: ([.\d]+)!;
 
     @ISA = qw(Exporter);
     @EXPORT_OK  = qw(ac_info ac_path ac_flags);
@@ -38,13 +36,13 @@ BEGIN {
         INSTALL_SCRIPT => '${INSTALL}',
         INSTALL_DATA => '${INSTALL} -m 644',
         PACKAGE => 'lire',
-        VERSION => '2.1.1',
+        VERSION => '2.1',
         SHELL => '/bin/bash',
         CFLAGS => '@CFLAGS@',
         CPPFLAGS => '@CPPFLAGS@',
         CXXFLAGS => '@CXXFLAGS@',
         FFLAGS => '@FFLAGS@',
-        DEFS => '-DPACKAGE_NAME=\"\" -DPACKAGE_TARNAME=\"\" -DPACKAGE_VERSION=\"\" -DPACKAGE_STRING=\"\" -DPACKAGE_BUGREPORT=\"\" -DPACKAGE_URL=\"\" -DPACKAGE=\"lire\" -DVERSION=\"2.1.1\"',
+        DEFS => '-DPACKAGE_NAME=\"\" -DPACKAGE_TARNAME=\"\" -DPACKAGE_VERSION=\"\" -DPACKAGE_STRING=\"\" -DPACKAGE_BUGREPORT=\"\" -DPACKAGE=\"lire\" -DVERSION=\"2.1\"',
         LDFLAGS => '@LDFLAGS@',
         LIBS => '',
         PERL => '/usr/bin/perl',
@@ -102,7 +100,7 @@ override certain parameters.
 
 =head1 VERSION
 
-$Id: Build.pm.in,v 1.9 2011/11/15 16:33:00 wraay Exp $
+$Id: Build.pm.in,v 1.8 2006/07/23 13:16:30 vanbaal Exp $
 
 =head1 COPYRIGHT
 
