@@ -24,7 +24,7 @@ __END__
 
 =head1 VERSION
 
-$Id: ListSpec.pm,v 1.3 2004/05/27 14:58:29 flacoste Exp $
+$Id: ListSpec.pm,v 1.4 2006/07/23 13:16:30 vanbaal Exp $
 
 =head1 AUTHORS
 
@@ -50,7 +50,6 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program (see COPYING); if not, check with
-http://www.gnu.org/copyleft/gpl.html or write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
+http://www.gnu.org/copyleft/gpl.html.
 
 =cut
