@@ -393,14 +393,14 @@ sub dlf_streams {
     my $self = $_[0];
 
     my @streams = ();
-    # patch from Jean-Benoit Marzio, see:
-    # http://lists.logreport.org/pipermail/questions/2010/000861.html
-    my @table_list = $self->{'_dbh'}->tables;
-    foreach my $table ( @table_list) {
-        next unless $table =~ /dlf_(.*)"/;
-        next if $table =~ /_links$/;
+    my $sth = $self->{'_dbh'}->table_info( "", "", "dlf_%", "TABLE" );
+    $sth->execute();
+    while ( my $table_info = $sth->fetchrow_hashref() ) {
+        next unless $table_info->{'TABLE_NAME'} =~ /^dlf_(.*)/;
+        next if $table_info->{'TABLE_NAME'} =~ /_links$/;
         push @streams, $1;
     }
+    $sth->finish();
 
     return @streams;
 }
@@ -828,7 +828,7 @@ Lire::DlfConverter(3pm)
 
 =head1 VERSION
 
-$Id: DlfStore.pm,v 1.41 2011/11/15 16:48:40 wraay Exp $
+$Id: DlfStore.pm,v 1.40 2008/07/17 13:47:14 wraay Exp $
 
 =head1 COPYRIGHT
 
