@@ -62,7 +62,13 @@ sub test_build_avg_query {
                       [ 'avgTest_total', 'sum("file-size")',
                         'avgTest_n', 'lr_count_uniq("connection-id",user)',
                         'avgTest', 'sum("file-size")/lr_count_uniq("connection-id",user)'
-                      ],] )
+                      ] ],
+                      [ 'file-size', undef, [ 'time_taken' ],
+                        [ 'avgTest_total', 'sum("file-size")',
+                          'avgTest_n', 'sum(time_taken)',
+                          'avgTest', 'sum("file-size")/sum(time_taken)'
+                        ] ],
+                      )
     {
         my ( $field, $weight, $by_fields, $aggrFields ) = @$t;
 
